<?php

namespace Drupal\simpleviews\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Form\FormBuilder;
use Psr\Log\LoggerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Simple Views Controller.
 */
class SimpleViewsController extends ControllerBase {

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilder
   */
  protected $formBuilder;

  /**
   * The logger.
   *
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * SimpleViewsController constructor.
   *
   * @param \Drupal\Core\Form\FormBuilder $formBuilder
   *   The form builder.
   * @param \Psr\Log\LoggerInterface $logger
   *   The logger.
   */
  public function __construct(FormBuilder $formBuilder, LoggerInterface $logger) {
    $this->formBuilder = $formBuilder;
    $this->logger = $logger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    /** @var \Drupal\Core\Form\FormBuilder $formBuilder */
    $formBuilder = $container->get('form_builder');

    /** @var \Psr\Log\LoggerInterface $logger */
    $logger = $container->get('logger.factory')->get('simpleviews');

    return new static($formBuilder, $logger);
  }

  /**
   * Checks access for SimpleViews pages.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The user account.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account) {
    return AccessResult::allowedIfHasPermission($account, 'administer simpleviews');
  }

  /**
   * Form builder callback.
   */
  public function form(Request $request) {
    // Get the current route.
    $current_route = $request->attributes->get('_route');

    // Check the current route to determine which form to display.
    if ($current_route == 'simpleviews.form') {
      // Load the form for creating a new view.
      $form = $this->formBuilder->getForm('\Drupal\simpleviews\Form\SimpleViewsForm');
    }
    elseif ($current_route == 'simpleviews.form_list') {
      // Load the form for listing existing views.
      $form = $this->formBuilder->getForm('\Drupal\simpleviews\Form\SimpleViewsFormList');
    }
    elseif ($current_route == 'simpleviews.form_edit') {
      // Load the form for listing existing views.
      $form = $this->formBuilder->getForm('\Drupal\simpleviews\Form\SimpleViewsForm');
    }
    else {
      // Handle other routes or unknown routes.
      // You may want to throw an exception or redirect to a default route.
      $this->logger->error('Invalid route: @route', ['@route' => $current_route]);
      throw new NotFoundHttpException();
    }

    return $form;
  }

}
