<?php

namespace Drupal\simpleviews\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\views\Entity\View;

/**
 * Provides a confirmation form for deleting a view.
 */
class SimpleViewsDeleteForm extends ConfirmFormBase {

  /**
   * The view entity to be deleted.
   *
   * @var \Drupal\views\Entity\View
   */
  protected $view;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simpleviews_delete_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete the view %label?', ['%label' => $this->view->label()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return Url::fromRoute('simpleviews.form_list');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $view_id = NULL) {
    $this->view = View::load($view_id);
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->view->delete();
    $this->messenger()->addMessage($this->t('The view %label has been deleted.', ['%label' => $this->view->label()]));
    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
